A Pelican Blog

# Second article

This is some article, in english

# Other articles

1. # A markdown powered article

   You're mutually oblivious.

   read more

2. # Article 1

   Article 1

   read more

3. # Article 2

   Article 2

   read more

4. # Article 3

   Article 3

   read more

5. # This is a super article !

   Multi-line metadata should be supported as well as inline markup.

   read more

6. # Oh yeah !

   ## Why not ?

   After all, why not ? It's pretty simple to do it, and it will allow me to write my blogposts in rst ! YEAH !

   read more

7. # Unbelievable !

   Or completely awesome. Depends the needs.

   read more